==> hs-cairo-0.12.3.1p2.tgz: lib/ghc/cairo-0.12.3.1/register.sh <==
#!/bin/sh
echo 'name: cairo
version: 0.12.3.1
id: cairo-0.12.3.1-6f21c8a5ac9f94b82a99988c05148ef2

license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the Cairo library.
description: Cairo is a library to render high quality vector graphics. There
             exist various backends that allows rendering to Gtk windows, PDF,
             PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
pkgpath: graphics/hs-cairo
exposed: True
exposed-modules: Graphics.Rendering.Cairo
                 Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types
                 Graphics.Rendering.Cairo.Internal
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
trusted: False
import-dirs: /usr/local/lib/ghc/cairo-0.12.3.1
library-dirs: /usr/local/lib/ghc/cairo-0.12.3.1 /usr/local/lib
hs-libraries: HScairo-0.12.3.1
extra-libraries: z cairo
extra-ghci-libraries:
include-dirs: /usr/local/include/cairo /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/local/include
              /usr/X11R6/include/pixman-1 /usr/X11R6/include
              /usr/X11R6/include/freetype2 /usr/include
              /usr/local/include/libpng16
includes:
depends: array-0.4.0.1-6380782b62ead58fec616aa07dc0e15c
         base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
         bytestring-0.10.0.2-f858e0cb19bca2e9549882fc8424f656
         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
hugs-options:
cc-options:
ld-options: "-Wl,-rpath-link,/usr/X11R6/lib"
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-cairo-0.12.3.1/html/cairo.haddock
haddock-html: /usr/local/share/doc/hs-cairo-0.12.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-cairo-0.12.5.3.tgz: lib/ghc/cairo-0.12.5.3/register.sh <==
#!/bin/sh
export PATH='/usr/obj/hs-cairo-0.12.5.3/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: cairo
version: 0.12.5.3
id: cairo-0.12.5.3-60c469fc414ed18be9b2430b7c406ed1

license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the Cairo library.
description: Cairo is a library to render high quality vector graphics. There
             exist various backends that allows rendering to Gtk windows, PDF,
             PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
pkgpath: graphics/hs-cairo
exposed: True
exposed-modules: Graphics.Rendering.Cairo
                 Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types
                 Graphics.Rendering.Cairo.Internal
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
                Graphics.Rendering.Cairo.Internal.Region
trusted: False
import-dirs: /usr/local/lib/ghc/cairo-0.12.5.3
library-dirs: /usr/local/lib/ghc/cairo-0.12.5.3 /usr/local/lib
hs-libraries: HScairo-0.12.5.3
extra-libraries: z cairo
extra-ghci-libraries:
include-dirs: /usr/local/include/cairo /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/local/include
              /usr/X11R6/include/pixman-1 /usr/X11R6/include
              /usr/X11R6/include/freetype2 /usr/include
              /usr/local/include/libpng16
includes:
depends: array-0.5.0.0-470385a50d2b78598af85cfe9d988e1b
         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
         utf8-string-0.3.8-33d6cbdc649f1dd0048718c4b65b149b
hugs-options:
cc-options:
ld-options: "-Wl,-rpath-link,/usr/X11R6/lib"
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-cairo-0.12.5.3/html/cairo.haddock
haddock-html: /usr/local/share/doc/hs-cairo-0.12.5.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
